@@ -59,7 +59,7 @@ class Bot:
                         sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
     async def send_event(self, event):
-        tasks = [asyncio.create_task(middleware.pre(get_dispatcher_by_event(event, event["type"], self.token), self.reject))
+        tasks = [asyncio.create_task(middleware.pre(get_dispatcher_by_event(self.token, event, event["type"]), self.reject))
                  for middleware in self.middlewares if middleware.event_type in (event["type"], None)]
         await asyncio.gather(*tasks)
 
@@ -71,7 +71,7 @@ class Bot:
                  for handler in self.handlers if handler.event_type == event["type"]]
         await asyncio.gather(*tasks)
 
-        tasks = [asyncio.create_task(middleware.post(get_dispatcher_by_event(event, event["type"], self.token)))
+        tasks = [asyncio.create_task(middleware.post(get_dispatcher_by_event(self.token, event, event["type"])))
                  for middleware in self.middlewares if middleware.event_type in (event["type"], None)]
         await asyncio.gather(*tasks)
 
