@@ -1,6 +1,8 @@
 from typing import Optional
 import aiohttp
 
+from .core import get_event_params
+
 
 class Dispatcher:
     def __init__(self, event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None, post_id: int = None, owner_id: int = None):
@@ -56,43 +58,12 @@ class Dispatcher:
             await session.post("https://api.vk.com/method/messages.setActivity", params=params)
 
 
-def get_dispatcher_by_event(event: dict, event_type: str, token: str) -> Optional[Dispatcher]:
-    text = None
-    user_id = None
-    peer_id = None
-    post_id = None
-    owner_id = None
-
-    try:
-        if event_type == "message_new":
-            text = event["object"]["message"]["text"]
-            peer_id = event["object"]["message"]["peer_id"]
-            user_id = event["object"]["message"]["from_id"]
-
-        elif event_type == "message_edit":
-            text = event["object"]["text"]
-            peer_id = event["object"]["peer_id"]
-            user_id = event["object"]["from_id"]
-
-        elif event_type in ("wall_reply_new", "wall_reply_edit"):
-            text = event["object"]["text"]
-            owner_id = event["object"]["owner_id"]
-            user_id = event["object"]["from_id"]
-            post_id = event["object"]["post_id"]
-
-        elif event_type == "wall_post_new":
-            text = event["object"]["text"]
-            owner_id = event["object"]["owner_id"]
-            user_id = event["object"]["from_id"]
-            post_id = event["object"]["id"]
-
-        elif event_type in ("board_post_new", "board_post_edit"):
-            text = event["object"]["text"]
-            owner_id = event["group_id"]
-            user_id = event["object"]["from_id"]
-            post_id = event["object"]["topic_id"]
-
-    except KeyError:
-        return
+def get_dispatcher_by_event(token: str, event: dict, event_type: str) -> Optional[Dispatcher]:
+    event_params = get_event_params(event, event_type)
+    text = event_params["text"]
+    user_id = event_params["user_id"]
+    peer_id = event_params["peer_id"]
+    post_id = event_params["post_id"]
+    owner_id = event_params["owner_id"]
 
     return Dispatcher(event=event, token=token, text=text, user_id=user_id, peer_id=peer_id, post_id=post_id, owner_id=owner_id)
